"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getHeightFieldDefs = exports.getWeightFieldDefs = void 0;

var _parseWeight = require("../utils/parse-weight");

var _parseHeight = require("../utils/parse-height");

// @ts-check
const prompt = 'Interpreted value will appear here';

const getMessage = val => val ? "interpreted as: ".concat(val) : "Couldn't parse, please try again";
/** @param {WeightUnit} [preferredUnit] */


const getWeightFieldDefs = preferredUnit => {
  const parseThenRestate = val => (0, _parseWeight.parseThenRestateWeight)(val, preferredUnit);

  return [{
    label: 'Weight',
    name: 'weight_raw',
    subLabel: item => item.value ? getMessage(parseThenRestate(item.value)) : prompt,
    completenessTest: parseThenRestate,
    test: val => val && (parseThenRestate(val) ? null : 'Failed to parse'),
    onInput: true,
    tourVal: preferredUnit === 'lb' ? '125 lb' : '57 kg',
    inputWidth: '120px',
    getUpdates: val => ({
      weight_raw: val || '',
      weight: (0, _parseWeight.parseWeightInKg)(val, preferredUnit)
    })
  }, {
    name: 'weight',
    hidden: true
  }];
};
/** @param {HeightUnit} [preferredUnit] */


exports.getWeightFieldDefs = getWeightFieldDefs;

const getHeightFieldDefs = preferredUnit => {
  const parseThenRestate = val => (0, _parseHeight.parseThenRestateHeight)(val, preferredUnit);

  return [{
    label: 'Height',
    name: 'height_raw',
    subLabel: item => item.value ? getMessage(parseThenRestate(item.value)) : prompt,
    completenessTest: val => parseThenRestate(val),
    test: val => val && (parseThenRestate(val) ? null : 'Failed to parse'),
    onInput: true,
    tourVal: preferredUnit === 'in' ? '5\'7"' : '170cm',
    inputWidth: '120px',
    getUpdates: val => ({
      height_raw: val || '',
      height: (0, _parseHeight.parseHeightInCm)(val, preferredUnit)
    })
  }, {
    name: 'height',
    hidden: true
  }];
};

exports.getHeightFieldDefs = getHeightFieldDefs;