"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatDoseString = exports.addCommas = void 0;

var _toNumber = require("./to-number");

// @ts-check
const addCommas = input => new Intl.NumberFormat('en-US').format((0, _toNumber.toNumber)(input));
/**
 * Takes a dose and unit and returns a correctly formatted/spaced string
 *
 * This is a simple task, that is just annoying to do within components, etc.
 *
 * We want:
 * - A space between the dose and unit
 * - That space should only be there if the unit is present
 * - If we do not have a dose, we should return an empty string
 * - Final result should never have any leading, trailing, or extra spaces
 * - If the dose is a string we should first trim it by itself
 * - Dose can be 0, so we need to check for null
 *
 * @param {string | number | null} dose
 * @param {string | null} [unit]
 * @returns {string}
 */


exports.addCommas = addCommas;

const formatDoseString = (dose, unit) => {
  if (dose == null || dose === '' || // @ts-ignore
  isNaN(dose)) return '';
  if (typeof dose === 'string') dose = dose.trim();
  if (typeof unit === 'string') unit = unit.trim();
  if (!unit) return "".concat(dose);
  return "".concat(dose, " ").concat(unit).trim(); // The trim here is superfluous
};

exports.formatDoseString = formatDoseString;