"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _formatNumber = require("./format-number");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const tests = [[null, '0'], [undefined, '0'], [0, '0'], [1234.75, '1,234.75'], [549000000, '549,000,000'], [549000000.2432423423, '549,000,000.243'], [1234, '1,234'], [100, '100']];
(0, _tape.default)('addCommas', t => {
  tests.forEach(([input, output]) => {
    t.equal((0, _formatNumber.addCommas)(input), output, "".concat(input, " should be ").concat(output));
  });
  t.end();
});
(0, _tape.default)('formatDoseString', t => {
  t.equal((0, _formatNumber.formatDoseString)(null, 'mg'), '', 'Return empty string for null dose');
  t.equal((0, _formatNumber.formatDoseString)(50, null), '50', 'Return string of dose when unit is null');
  t.equal((0, _formatNumber.formatDoseString)(null, null), '', 'Return empty string for both null dose and unit');
  t.equal((0, _formatNumber.formatDoseString)(undefined, 'mg'), '', 'Return empty string if dose is undefined');
  t.equal((0, _formatNumber.formatDoseString)(100), '100', 'Return string of dose when no unit is provided');
  t.equal((0, _formatNumber.formatDoseString)(100, 'mg'), '100 mg', 'Return correctly formatted string with numeric dose and unit');
  t.equal((0, _formatNumber.formatDoseString)('100', 'mg'), '100 mg', 'Return correctly formatted string with string dose and unit');
  t.equal((0, _formatNumber.formatDoseString)('   100  ', 'mg'), '100 mg', 'Trim dose string and return correctly formatted string');
  t.equal((0, _formatNumber.formatDoseString)(0, 'mg'), '0 mg', 'Handle zero dose correctly with unit');
  t.equal((0, _formatNumber.formatDoseString)('0', 'mg'), '0 mg', 'Handle string "0" as dose correctly');
  t.equal((0, _formatNumber.formatDoseString)('', 'mg'), '', 'Return empty string for empty string dose');
  t.equal((0, _formatNumber.formatDoseString)(100, ' mg '), '100 mg', 'Trim unit and return correctly formatted string');
  t.equal((0, _formatNumber.formatDoseString)(100, ''), '100', 'Return just the dose when unit is empty');
  t.equal((0, _formatNumber.formatDoseString)(NaN, 'mg'), '', 'Returns an empty string for NaN dose');
  t.end();
});