"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDateInputMaskForLocale = exports.getBrowserLocale = void 0;

/**
 * Returns browser locale.
 *
 * NB: we use the `Intl` object instead of `navigator.language` because in
 * Cypress tests when overriding locale for testing, it's harder to change
 * `navigator.language` and `navigator` is not available in Node.js.
 *
 * @returns {Intl.UnicodeBCP47LocaleIdentifier}
 */
const getBrowserLocale = () => {
  try {
    return Intl.DateTimeFormat().resolvedOptions().locale;
  } catch (e) {
    return 'en-US';
  }
};
/** @param {Intl.UnicodeBCP47LocaleIdentifier} [locale] */


exports.getBrowserLocale = getBrowserLocale;

const getDateInputMaskForLocale = locale => {
  const date = new Date(Date.UTC(2023, 11, 31, 0, 0, 0)); // Use a fixed date

  if (!locale) locale = getBrowserLocale();
  const formatter = new Intl.DateTimeFormat(locale, {
    year: 'numeric',
    month: '2-digit',
    day: '2-digit'
  }); // Get the parts and their order

  const parts = formatter.formatToParts(date); // Define masks for date components and a default for literals

  const masks = {
    day: 'dd',
    month: 'mm',
    year: 'yyyy',
    literal: '/'
  }; // Map parts to their corresponding masks, handling literals appropriately

  return parts.map(part => {
    if (part.type === 'literal') {
      // Return the actual literal value, which is the separator (e.g., '/', '-', etc.)
      return part.value;
    }

    return masks[part.type];
  }).join('');
};

exports.getDateInputMaskForLocale = getDateInputMaskForLocale;