"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _parseHeight = require("./parse-height");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// @ts-check
(0, _tape.default)('parse height', t => {
  /** @type {[input: string, output: string, heightInCm: number | null][]} */
  const inputsWithNonNumbers = [['30c', '30 cm', 30], ['30 centimeters', '30 cm', 30], ['50cm', '50 cm', 50], ["5-8", "5'8\"", 173], ["58i", "4'10\"", 147], ["58in", "4'10\"", 147], ["58 in.", "4'10\"", 147], ["58\"", "4'10\"", 147], ["58 inch", "4'10\"", 147], ["58inches", "4'10\"", 147], ["58 inches", "4'10\"", 147], ["5 feet", "5'0\"", 152], ["5f", "5'0\"", 152], ["5ft.0in", "5'0\"", 152], ["5ft. 0in", "5'0\"", 152], ["5ft", "5'0\"", 152], ["5'0\"", "5'0\"", 152], ["8'", "8'0\"", 244], ["6\u2019", "6'0\"", 183], ["58c", "58 cm", 58], ["58cm", "58 cm", 58], ["58 c.m.", "58 cm", 58], ["1.84m", "184 cm", 184], ["1.84Meters", "184 cm", 184], ["5'2", "5'2\"", 157], ["5 - 2", "5'2\"", 157], ["5- 2", "5'2\"", 157], ["5-2", "5'2\"", 157], ["5 -2", "5'2\"", 157], ["2.2", "220 cm", 220], ["4m", '', null], ["121in", '', null], ["1191", '', null], ["50 feet", '', null], ["5ft", "5'0\"", 152], ["120in", "10'0\"", 305], ["119in", "9'11\"", 302], ["119 Inches", "9'11\"", 302], // max in
  ['120in', '10\'0"', 305], ['121in', '', null], // max cm
  ['304cm', '304 cm', 304], ['305cm', '', null]];
  inputsWithNonNumbers.forEach(([input, output, heightInCm]) => {
    t.equal((0, _parseHeight.parseThenRestateHeight)(input, 'cm'), output, "parseThenRestateHeight(\"".concat(input, "\", \"cm\") === \"").concat(output, "\""));
    t.equal((0, _parseHeight.parseThenRestateHeight)(input, 'in'), output, "parseThenRestateHeight(\"".concat(input, "\", \"in\") === \"").concat(output, "\""));
    t.equal((0, _parseHeight.parseHeightInCm)(input, 'cm'), heightInCm, "parseHeightInCm(\"".concat(input, "\", \"cm\") === ").concat(heightInCm));
    t.equal((0, _parseHeight.parseHeightInCm)(input, 'in'), heightInCm, "parseHeightInCm(\"".concat(input, "\", \"in\") === ").concat(heightInCm));
  });
  /**
   * @type {[
   *   input: string,
   *   outputIfMetric: string,
   *   outputIfImperial: string,
   *   inCmIfMetric: number | null,
   *   inCmIfImperial: number | null
   * ][]}
   */

  const purelyNumeric = [// really big and small number can be
  // assumed to be metric, even if not explicit
  ['2.1', '210 cm', "210 cm", 210, 210], ['1.56', '156 cm', "156 cm", 156, 156], [".75", "75 cm", "75 cm", 75, 75], ["0.434", "43 cm", "43 cm", 43, 43], ["184", "184 cm", '184 cm', 184, 184], // This range of numbers is too small to be inches
  // or cm but is plausible for a veterinary height.
  ['5', '5 cm', "0'5\"", 5, 13], ['10', '10 cm', "0'10\"", 10, 25], ['15', '15 cm', "1'3\"", 15, 38], ['20', '20 cm', "1'8\"", 20, 51], ['25', '25 cm', "2'1\"", 25, 64], ['30', '30 cm', "2'6\"", 30, 76], ['35', '35 cm', "2'11\"", 35, 89], ['40', '40 cm', "3'4\"", 40, 102], ['45', '45 cm', "3'9\"", 45, 114], ['50', '50 cm', "4'2\"", 50, 127], ['55', '55 cm', "4'7\"", 55, 140], ['60', '60 cm', "5'0\"", 60, 152], ['65', '65 cm', "5'5\"", 65, 165], ['70', '70 cm', "5'10\"", 70, 178], ['75', '75 cm', "6'3\"", 75, 191], ['80', '80 cm', "6'8\"", 80, 203], ['85', '85 cm', "7'1\"", 85, 216], ['90', '90 cm', "7'6\"", 90, 229], ['95', '95 cm', "7'11\"", 95, 241], ['99', '99 cm', "8'3\"", 99, 251], // start assuming cm at this point
  ['100', '100 cm', '100 cm', 100, 100], ['190', '190 cm', '190 cm', 190, 190], ['200', '200 cm', '200 cm', 200, 200], ['304', '304 cm', '304 cm', 304, 304], // // past max cm also
  ['305', '', '', null, null]];
  purelyNumeric.forEach(([input, outputIfMetric, outputIfImperial, inCmIfMetric, inCmIfImperial]) => {
    t.equal((0, _parseHeight.parseThenRestateHeight)(input, 'cm'), outputIfMetric, "parseThenRestateHeight(\"".concat(input, "\", \"cm\") === \"").concat(outputIfMetric, "\""));
    t.equal((0, _parseHeight.parseThenRestateHeight)(input, 'in'), outputIfImperial, "parseThenRestateHeight(\"".concat(input, "\", \"in\") === \"").concat(outputIfImperial, "\""));
    t.equal((0, _parseHeight.parseHeightInCm)(input, 'cm'), inCmIfMetric, "parseHeightInCm(\"".concat(input, "\", \"cm\") === ").concat(inCmIfMetric));
    t.equal((0, _parseHeight.parseHeightInCm)(input, 'in'), inCmIfImperial, "parseHeightInCm(\"".concat(input, "\", \"in\") === ").concat(inCmIfImperial));
  });
  const outliers = [[null, ''], [undefined, ''], ['0', ''], ['-1', '']];
  outliers.forEach(([input, output]) => {
    t.equal((0, _parseHeight.parseThenRestateHeight)(input, 'cm'), output, "parseThenRestateHeight(\"".concat(input, "\", \"cm\") === \"").concat(output, "\""));
    t.equal((0, _parseHeight.parseThenRestateHeight)(input, 'in'), output, "parseThenRestateHeight(\"".concat(input, "\", \"in\") === \"").concat(output, "\""));
  });
  t.end();
});