"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _parseWeight = require("./parse-weight");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// @ts-check
(0, _tape.default)('parse weight with preferred unit', t => {
  /**
   * @type {[
   *   input: string,
   *   outputIfLbs: string,
   *   outputIfKg: string,
   *   kgOutputIfLbs: number,
   *   kgOutputIfKg: number
   * ][]}
   */
  const results = [['0', '', '', null, null], ['200', '200 lb', '200 kg', 91, 200], ["184", '184 lb', "184 kg", 83, 184], ["84l", '84 lb', '84 lb', 38, 38], // sanity checks
  ["845k", '', '', null, null], ["700", '700 lb', '', 318, null], // potentially valid lbs, but not kg
  ["-45", '', '', null, null], // can override with specific unit
  ['35lbs sdsf', '35 lb', '35 lb', 16, 16], ['35kg sdsf', '35 kg', '35 kg', 35, 35]];
  results.forEach(([input, expectedIfLbs, expectedIfKg, kgOutputIfLbs, kgOutputIfKg]) => {
    t.equal((0, _parseWeight.parseThenRestateWeight)(input, 'lb'), expectedIfLbs, "parseThenRestateWeight('".concat(input, "', 'lb') to equal \"").concat(expectedIfLbs, "\""));
    t.equal((0, _parseWeight.parseThenRestateWeight)(input, 'kg'), expectedIfKg, "parseThenRestateWeight('".concat(input, "', 'kg')  to equal \"").concat(expectedIfKg, "\""));
    t.equal((0, _parseWeight.parseWeightInKg)(input, 'lb'), kgOutputIfLbs, "parseWeightInKg('".concat(input, "', 'lb') to equal \"").concat(kgOutputIfLbs, "\""));
    t.equal((0, _parseWeight.parseWeightInKg)(input, 'kg'), kgOutputIfKg, "parseWeightInKg('".concat(input, "', 'kg') to equal \"").concat(kgOutputIfKg, "\""));
  });
  t.end();
});